/*
 *	@name		GlobusDRS_MS.h
 *	@author		Christian Loeschen, TU Dresden
 *	@license	BSD
*/


/*
 *	iRODS Microservice that takes an iRODS file, transfers it to a
 *	destination location, and registers it with a designated logical name.
 *
 *	@param P_rlsUrl			msParam_t containing the URL of the Globus RLS.
 *	@param P_options		msParam_t containing additional options for the globus-credential-client command.
 *	@param P_rodsFile		msParam_t containing the source iRODS file.
 *	@param P_LFN			msParam_t containing the destination LFN.
 *	@param P_destUrl		msParam_t containing the URL of the destination file.
 *	@param P_out			msParam_t to write the result to.
 *	@param rei				iRODS ruleExecutionInfo structure
 *	@return					1 on success, on error -344000 (EXEC_CMD_ERROR)
 */
int msiGlobusReplicationPut(
		msParam_t* P_rlsUrl,
		msParam_t* P_options,
		msParam_t* P_rodsFile,
		msParam_t* P_LFN,
		msParam_t* P_destUrl,
		msParam_t* P_out,
		ruleExecInfo_t *rei);


/*
 *	iRODS Microservice that looks up a replica using its logical name, randomly
 *	selects a replica source location, and gets the file to a local iRODS file.
 *
 *	@param P_rlsUrl			msParam_t containing the URL of the Globus RLS.
 *	@param P_options		msParam_t containing additional options for the globus-credential-client command.
 *	@param P_LFN			msParam_t containing the source LFN.
 *	@param P_rodsFile		msParam_t containing the destination iRODS file.
 *	@param P_out			msParam_t to write the result to.
 *	@param rei				iRODS ruleExecutionInfo structure
 *	@return					1 on success, on error -344000 (EXEC_CMD_ERROR)
 */
int msiGlobusReplicationGet(
		msParam_t* P_rlsUrl,
		msParam_t* P_options,
		msParam_t* P_LFN,
		msParam_t* P_rodsFile,
		msParam_t* P_out,
		ruleExecInfo_t *rei);


/*
 *	iRODS Microservice that looks up a replica using its logical name, randomly
 *	selects a replica source location, and performs a thrid-party transfer to a
 *	remote location. It does not register the new copy in the RLS, hence the new
 *	remote file is called a copy not a replica.
 *
 *	@param P_rlsUrl			msParam_t containing the URL of the Globus RLS.
 *	@param P_options		msParam_t containing additional options for the globus-credential-client command.
 *	@param P_LFN			msParam_t containing the source LFN.
 *	@param P_destUrl		msParam_t containing the URL of the destination file.
 *	@param P_out			msParam_t to write the result to.
 *	@param rei				iRODS ruleExecutionInfo structure
 *	@return					1 on success, on error -344000 (EXEC_CMD_ERROR)
 */
int msiGlobusReplicationCopy(
		msParam_t* P_rlsUrl,
		msParam_t* P_options,
		msParam_t* P_LFN,
		msParam_t* P_destUrl,
		msParam_t* P_out,
		ruleExecInfo_t *rei);


/*
 *	iRODS Microservice that registers data specified by url under a given logical
 *	name in the RLS.
 *
 *	@param P_rlsUrl			msParam_t containing the URL of the Globus RLS.
 *	@param P_options		msParam_t containing additional options for the globus-credential-client command.
 *	@param P_LFN			msParam_t containing the LFN to register a replica.
 *	@param P_destUrl		msParam_t containing the URL of the replica file.
 *	@param P_out			msParam_t to write the result to.
 *	@param rei				iRODS ruleExecutionInfo structure
 *	@return					1 on success, on error -344000 (EXEC_CMD_ERROR)
 */
int msiGlobusReplicationRegister(
		msParam_t* P_rlsUrl,
		msParam_t* P_options,
		msParam_t* P_LFN,
		msParam_t* P_destUrl,
		msParam_t* P_out,
		ruleExecInfo_t *rei);


/*
 *	iRODS Microservice that looks up a replica using its logical name, randomly
 *	selects a replica source location, and performs a thrid-party transfer to a
 *	remote location. The new file is registered in the RLS as another replica
 *	associated with the logical name.
 *
 *	@param P_rlsUrl			msParam_t containing the URL of the Globus RLS.
 *	@param P_options		msParam_t containing additional options for the globus-credential-client command.
 *	@param P_LFN			msParam_t containing the source LFN.
 *	@param P_destUrl		msParam_t containing the URL of the destination file.
 *	@param P_out			msParam_t to write the result to.
 *	@param rei				iRODS ruleExecutionInfo structure
 *	@return					1 on success, on error -344000 (EXEC_CMD_ERROR)
 */
int msiGlobusReplicationReplicate(
		msParam_t* P_rlsUrl,
		msParam_t* P_options,
		msParam_t* P_LFN,
		msParam_t* P_destUrl,
		msParam_t* P_out,
		ruleExecInfo_t *rei);


/*
 *	iRODS Microservice that deletes the specific instance of the replicated data.
 *
 *	@param P_rlsUrl			msParam_t containing the URL of the Globus ReplicationService.
 *	@param P_options		msParam_t containing additional options for the globus-credential-client command.
 *	@param P_LFN			msParam_t containing the destination LFN.
 *	@param P_destUrl		msParam_t containing the URL of the file to delete.
 *	@param P_out			msParam_t to write the result to.
 *	@param rei				iRODS ruleExecutionInfo structure
 *	@return					1 on success, on error -344000 (EXEC_CMD_ERROR)
 */
int msiGlobusReplicationDelete(
		msParam_t* P_rlsUrl,
		msParam_t* P_options,
		msParam_t* P_LFN,
		msParam_t* P_destUrl,
		msParam_t* P_out,
		ruleExecInfo_t *rei);
